{{ organization }} Wi-Fi Service

# Get connected to the Internet for free

A simple, no frills {{ organization }} Wi-Fi service.

## Login using Facebook

Terms of Usage
×

## Terms of Usage

This is a {{ organization }} free Hotspot wireless internet Service (the “Service”) provided for use by customers. All users are required to log-in individually as an independent user.

The Service is made available provided:

(a) You do not use the Service for anything unlawful, immoral or improper;

(b) You do not use the Service to make offensive or nuisance communications in whatever form. Such usage includes posting, transmitting, uploading, downloading or otherwise facilitating any content that is unlawful, defamatory, threatening, a nuisance, obscene, hateful, abusive, harmful (including but not limited to viruses, corrupted files, or any other similar software or programs), a breach of privacy, or which is otherwise objectionable;

(c) You do not use the Service to harm or attempt to harm minors in any way;

(d) You do not act nor knowingly permit others to act in such a way that the operation of the Service or our systems will be jeopardized or impaired;

(e) You do not use abusive or threatening behavior towards other users of the Service, members of our staff or any person in the vicinity of a Wireless LAN Hotspot;

(f) You do not use the Service to access or use content in a way that infringes the rights of others;

(g) The Service is used in accordance with any third party policies for acceptable use or any relevant internet standards (where applicable).

(h) You agree not to resell or re-broadcast any aspect of the Service, whether for profit or otherwise. You accept that your entitlement to use the Service is for your personal use only and that you shall not be entitled to transfer your entitlement to use the Service to any other person or allow any other person to make use of the Service or of any username or password or other entitlement supplied to you in connection with the Service.

(i) You also agree not to modify the Unit or use the Service for any fraudulent purpose, or in such a way as to create damage or risk to our business, reputation, employees, subscribers, facilities, third parties or to the public generally.

(j) You have no proprietary or ownership rights to any username or password or to a specific IP address, or e-mail address assigned to you or your Unit. We may change such addresses at any time or deactivate or suspend Service to any address without prior notice to you if we suspect any unlawful or fraudulent use of the services.